@@ -3,6 +3,7 @@
  */
 #ifndef eslKEYHASH_INCLUDED
 #define eslKEYHASH_INCLUDED
+#include "esl_config.h"
 
 #include <stdio.h>		/* for FILE */
 
@@ -59,12 +60,4 @@ extern int  esl_keyhash_Lookup(const ESL_KEYHASH *kh, const char *key, esl_pos_t
 
 
 #endif /* eslKEYHASH_INCLUDED */
-/*****************************************************************
- * Easel - a library of C functions for biological sequence analysis
- * Version 0.43; July 2016
- * Copyright (C) 2016 Howard Hughes Medical Institute
- * Other copyrights also apply. See the LICENSE file for a full list.
- * 
- * Easel is open source software, distributed under the BSD license. See
- * the LICENSE file for more details.
- *****************************************************************/
+
