@@ -1,15 +1,12 @@
 /* Mixture generalized extreme value distributions.
  * 
  * SRE, Mon Aug 15 08:33:57 2005 [St. Louis]
- * SVN $Id$
- * SVN $URL$
  */
 #ifndef eslMIXGEV_INCLUDED
 #define eslMIXGEV_INCLUDED
-
-#ifdef eslAUGMENT_RANDOM
+#include "esl_config.h"
+#include <stdio.h>
 #include "esl_random.h"
-#endif
 
 typedef struct {
   double *q;			/* mixture coefficients      [0..K-1]*/
@@ -45,25 +42,12 @@ extern int         esl_mixgev_Plot(FILE *fp, ESL_MIXGEV *mg,
 				   double (*func)(double x, ESL_MIXGEV *mg), 
 				   double xmin, double xmax, double xstep);
 
-#ifdef eslAUGMENT_RANDOM
 extern double      esl_mixgev_Sample(ESL_RANDOMNESS *r, ESL_MIXGEV *mg);
 extern int         esl_mixgev_FitGuess(ESL_RANDOMNESS *r, double *x, int n, 
 				       ESL_MIXGEV *mg);
-#endif /*eslAUGMENT_RANDOM*/
 
-
-#ifdef eslAUGMENT_MINIMIZER
 extern int         esl_mixgev_FitComplete(double *x, int n, ESL_MIXGEV *mg);
-#endif /*eslAUGMENT_MINIMIZER*/
 
 
 #endif /*eslMIXGEV_INCLUDED*/
-/*****************************************************************
- * Easel - a library of C functions for biological sequence analysis
- * Version 0.43; July 2016
- * Copyright (C) 2016 Howard Hughes Medical Institute
- * Other copyrights also apply. See the LICENSE file for a full list.
- * 
- * Easel is open source software, distributed under the BSD license. See
- * the LICENSE file for more details.
- *****************************************************************/
+
