@@ -260,6 +260,7 @@ esl_stopwatch_Include(ESL_STOPWATCH *master, ESL_STOPWATCH *w)
 /*****************************************************************
  * Portable high resolution timing
  *****************************************************************/
+#ifdef eslSTOPWATCH_HIGHRES
 
 /* The following code is
  * (C) 2012 David Robert Nadeau, http://NadeauSoftware.com
@@ -370,7 +371,7 @@ stopwatch_getRealTime(void)
 	return -1.0;		/* Failed. */
 #endif
 }
-
+#endif /*eslSTOPWATCH_HIGHRES*/
 
 /*****************************************************************
  * Example of using the stopwatch module
@@ -411,16 +412,4 @@ main(void)
 /*::cexcerpt::stopwatch_example::end::*/
 #endif /*ESL_STOPWATCH_EXAMPLE*/
 
-/*****************************************************************
- * Easel - a library of C functions for biological sequence analysis
- * Version 0.43; July 2016
- * Copyright (C) 2016 Howard Hughes Medical Institute
- * Other copyrights also apply. See the LICENSE file for a full list.
- * 
- * Easel is open source software, distributed under the BSD license. See
- * the LICENSE file for more details.
- *
- * SVN $Id$
- * SVN $URL$
- *****************************************************************/
 
