@@ -5,11 +5,6 @@
  *   1. The CM_ALIDISPLAY object.
  *   2. The CM_ALIDISPLAY API.
  *   3. Debugging/dev code.
- *   4. Benchmark driver.
- *   5. Unit tests.
- *   6. Test driver.
- *   7. Example.
- *   8. Copyright and license.
  */
 #include "esl_config.h"
 #include "p7_config.h"
@@ -154,7 +149,7 @@ cm_alidisplay_Create(CM_t *cm, char *errbuf, CM_ALNDATA *adata, const ESL_SQ *sq
     v    = tr->state[ti];
     mode = tr->mode[ti];
     if (v == cm->M) {  /* special case: local exit into EL */
-      nd = cm->ndidx[tr->state[ti-1]]; /* calculate node that EL replaced */
+      nd = 1 + cm->ndidx[tr->state[ti-1]]; /* calculate node that EL replaced */
       qinset = cm->cmcons->rpos[nd] - cm->cmcons->lpos[nd] + 1;
       tinset = tr->emitr[ti]  - tr->emitl[ti]  + 1;
       ninset = ESL_MAX(qinset,tinset);
@@ -213,10 +208,10 @@ cm_alidisplay_Create(CM_t *cm, char *errbuf, CM_ALNDATA *adata, const ESL_SQ *sq
     len += wtrunc_L;
   }
 #if eslDEBUGLEVEL >= 1
-  printf("cfrom_span: %4d\n", cfrom_span);
-  printf("cfrom_emit: %4d\n", cfrom_emit);
-  printf("cto_emit:   %4d\n", cto_emit);
-  printf("cto_span:   %4d\n", cto_span);
+  printf("#DEBUG: cfrom_span: %4d\n", cfrom_span);
+  printf("#DEBUG: cfrom_emit: %4d\n", cfrom_emit);
+  printf("#DEBUG: cto_emit:   %4d\n", cto_emit);
+  printf("#DEBUG: cto_span:   %4d\n", cto_span);
 #endif
   
   /* Create strings of the full model and sequence used in an output
@@ -1174,8 +1169,8 @@ cm_alidisplay_Print(FILE *fp, CM_ALIDISPLAY *ad, int min_aliwidth, int linewidth
       
   /* dynamically size the output lines */
   namewidth  = ESL_MAX(strlen(show_cmname), strlen(show_seqname));
-  coordwidth = ESL_MAX(ESL_MAX(integer_textwidth(ad->cfrom_emit),
-			       integer_textwidth(ad->cto_emit)),
+  coordwidth = ESL_MAX(ESL_MAX(integer_textwidth(ad->cfrom_span),
+			       integer_textwidth(ad->cto_span)),
 		       ESL_MAX(integer_textwidth(ad->sqfrom),
 			       integer_textwidth(ad->sqto)));
   aliwidth   = (linewidth > 0) ? linewidth - namewidth - 2*coordwidth - 5 : ad->N;
@@ -1579,25 +1574,3 @@ cm_alidisplay_Compare(const CM_ALIDISPLAY *ad1, const CM_ALIDISPLAY *ad2)
 
 
 
-/*****************************************************************
- * 4. Benchmark driver.
- *****************************************************************/
-/****************************************************************
- * 5. Unit tests.
- ****************************************************************/
-/*****************************************************************
- * 6. Test driver.
- *****************************************************************/
-/*****************************************************************
- * 7. Example.
- *****************************************************************/
-/*****************************************************************
- * Infernal - inference of RNA secondary structure alignments
- * Version 1.1.2; July 2016
- * Copyright (C) 2016 Howard Hughes Medical Institute.
- * Other copyrights also apply. See the COPYRIGHT file for a full list.
- * 
- * Infernal is distributed under the terms of the GNU General Public License
- * (GPLv3). See the LICENSE file for details.
- *****************************************************************/
-
