@@ -5,6 +5,9 @@
  * Robert J. Klein
  * February 25, 2002
  */
+#include "esl_config.h"
+#include "p7_config.h"
+#include "config.h"
 
 #include <stdlib.h>
 #include <string.h>
@@ -17,8 +20,9 @@
 #include "esl_vectorops.h"
 #include "esl_wuss.h"
 
-#include "funcs.h"
-#include "structs.h"
+#include "hmmer.h"
+
+#include "infernal.h"
 
 static matrix_t *setup_matrix (int size);
 static float simple_identity(const ESL_ALPHABET *abc, char *s1, char *s2);
@@ -946,7 +950,7 @@ int ribosum_MSA_resolve_degeneracies(fullmat_t *fullmat, ESL_MSA *msa)
     {
       if (esl_abc_CIsGap(fullmat->abc, msa->aseq[0][apos])) continue; /* we can still have gaps in 1 seq MSA, they'll
 								       * be dealt with (ignored) in 
-								       * modelmaker.c:HandModelMaker() */
+								       * modelmaker.c:HandModelmaker() */
       mate = ct[(apos+1)]; /* apos is 0..alen-1, ct is 1..alen, so mate will be 1..alen now */
       if(mate != 0 && esl_abc_CIsGap(msa_abc, msa->aseq[0][(mate-1)])) mate = 0; 
       /* apos is a base paired res, but mate is a gap, pretend apos is SS for our purposes here */
@@ -1071,7 +1075,7 @@ int ribosum_MSA_resolve_degeneracies(fullmat_t *fullmat, ESL_MSA *msa)
     if(cp == NULL) ESL_XEXCEPTION(eslEINVAL, "ribosum_MSA_resolve_degeneracies(), second pass check character %d (%c) is still ambiguous!\n", apos, c);
   }
 
-  if((status = esl_msa_Digitize(msa_abc, msa)) != eslOK) goto ERROR;
+  if((status = esl_msa_Digitize(msa_abc, msa, NULL)) != eslOK) goto ERROR;
   free(unpaired_marginals);
   free(paired_marginals);
   free(cur_unpaired_marginals);
